==> pegasus-merchandise-api-3.2.0-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpFinalPriceVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class OpFinalPriceVO implements Serializable {

    private Integer id;
    private String title1;
    private String title2;
    private String title3;
    private String titleCopywriterColor;
    private String moneyCopywriterColor;
    private String backgroundImageUrl;
    private String operatorNote;
    private Integer status;
    private String statusDesc;
    private Integer createId;
    private String createNickname;
    private Date createTime;
    private Date updateTime;
    private Date startTime;
    private Date endTime;
    private Integer updateId;
    private String updateNickname;
    private Integer isDeleted;

    private List<OpFinalPriceProdVO> prodList;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }


    public String getTitle1() {
        return title1;
    }


    public void setTitle1(String title1) {
        this.title1 = title1 == null ? null : title1.trim();
    }


    public String getTitle2() {
        return title2;
    }


    public void setTitle2(String title2) {
        this.title2 = title2 == null ? null : title2.trim();
    }


    public String getTitle3() {
        return title3;
    }


    public void setTitle3(String title3) {
        this.title3 = title3 == null ? null : title3.trim();
    }

    public String getTitleCopywriterColor() {
        return titleCopywriterColor;
    }


    public void setTitleCopywriterColor(String titleCopywriterColor) {
        this.titleCopywriterColor = titleCopywriterColor == null ? null : titleCopywriterColor.trim();
    }


    public String getMoneyCopywriterColor() {
        return moneyCopywriterColor;
    }


    public void setMoneyCopywriterColor(String moneyCopywriterColor) {
        this.moneyCopywriterColor = moneyCopywriterColor == null ? null : moneyCopywriterColor.trim();
    }


    public String getBackgroundImageUrl() {
        return backgroundImageUrl;
    }


    public void setBackgroundImageUrl(String backgroundImageUrl) {
        this.backgroundImageUrl = backgroundImageUrl == null ? null : backgroundImageUrl.trim();
    }


    public String getOperatorNote() {
        return operatorNote;
    }

    public void setOperatorNote(String operatorNote) {
        this.operatorNote = operatorNote == null ? null : operatorNote.trim();
    }


    public Integer getStatus() {
        return status;
    }


    public void setStatus(Integer status) {
        this.status = status;
    }


    public String getStatusDesc() {
        return statusDesc;
    }

    public void setStatusDesc(String statusDesc) {
        this.statusDesc = statusDesc;
    }

    public Integer getCreateId() {
        return createId;
    }


    public void setCreateId(Integer createId) {
        this.createId = createId;
    }


    public String getCreateNickname() {
        return createNickname;
    }


    public void setCreateNickname(String createNickname) {
        this.createNickname = createNickname == null ? null : createNickname.trim();
    }


    public Date getCreateTime() {
        return createTime;
    }


    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }


    public Date getUpdateTime() {
        return updateTime;
    }


    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }



    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }


    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }


    public Integer getUpdateId() {
        return updateId;
    }

    public void setUpdateId(Integer updateId) {
        this.updateId = updateId;
    }

    public String getUpdateNickname() {
        return updateNickname;
    }

    public void setUpdateNickname(String updateNickname) {
        this.updateNickname = updateNickname;
    }


    public List<OpFinalPriceProdVO> getProdList() {
        return prodList;
    }

    public void setProdList(List<OpFinalPriceProdVO> prodList) {
        this.prodList = prodList;
    }

}

==> pegasus-merchandise-api-1009628-20251212.094020-1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpFinalPriceVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class OpFinalPriceVO implements Serializable {

    private Integer id;
    private String title1;
    private String title2;
    private String title3;
    private String titleCopywriterColor;
    private String moneyCopywriterColor;
    private String backgroundImageUrl;
    private String operatorNote;
    private Integer status;
    private String statusDesc;
    private Integer createId;
    private String createNickname;
    private Date createTime;
    private Date updateTime;
    private Date startTime;
    private Date endTime;
    private Integer updateId;
    private String updateNickname;
    private Integer isDeleted;

    private Integer type;

    private List<OpFinalPriceProdVO> prodList;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }


    public String getTitle1() {
        return title1;
    }


    public void setTitle1(String title1) {
        this.title1 = title1 == null ? null : title1.trim();
    }


    public String getTitle2() {
        return title2;
    }


    public void setTitle2(String title2) {
        this.title2 = title2 == null ? null : title2.trim();
    }


    public String getTitle3() {
        return title3;
    }


    public void setTitle3(String title3) {
        this.title3 = title3 == null ? null : title3.trim();
    }

    public String getTitleCopywriterColor() {
        return titleCopywriterColor;
    }


    public void setTitleCopywriterColor(String titleCopywriterColor) {
        this.titleCopywriterColor = titleCopywriterColor == null ? null : titleCopywriterColor.trim();
    }


    public String getMoneyCopywriterColor() {
        return moneyCopywriterColor;
    }


    public void setMoneyCopywriterColor(String moneyCopywriterColor) {
        this.moneyCopywriterColor = moneyCopywriterColor == null ? null : moneyCopywriterColor.trim();
    }


    public String getBackgroundImageUrl() {
        return backgroundImageUrl;
    }


    public void setBackgroundImageUrl(String backgroundImageUrl) {
        this.backgroundImageUrl = backgroundImageUrl == null ? null : backgroundImageUrl.trim();
    }


    public String getOperatorNote() {
        return operatorNote;
    }

    public void setOperatorNote(String operatorNote) {
        this.operatorNote = operatorNote == null ? null : operatorNote.trim();
    }


    public Integer getStatus() {
        return status;
    }


    public void setStatus(Integer status) {
        this.status = status;
    }


    public String getStatusDesc() {
        return statusDesc;
    }

    public void setStatusDesc(String statusDesc) {
        this.statusDesc = statusDesc;
    }

    public Integer getCreateId() {
        return createId;
    }


    public void setCreateId(Integer createId) {
        this.createId = createId;
    }


    public String getCreateNickname() {
        return createNickname;
    }


    public void setCreateNickname(String createNickname) {
        this.createNickname = createNickname == null ? null : createNickname.trim();
    }


    public Date getCreateTime() {
        return createTime;
    }


    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }


    public Date getUpdateTime() {
        return updateTime;
    }


    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }



    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }


    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }


    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getUpdateId() {
        return updateId;
    }

    public void setUpdateId(Integer updateId) {
        this.updateId = updateId;
    }

    public String getUpdateNickname() {
        return updateNickname;
    }

    public void setUpdateNickname(String updateNickname) {
        this.updateNickname = updateNickname;
    }


    public List<OpFinalPriceProdVO> getProdList() {
        return prodList;
    }

    public void setProdList(List<OpFinalPriceProdVO> prodList) {
        this.prodList = prodList;
    }

}
